@@ -84,6 +84,9 @@
 /* Copy the first part of user declarations.  */
 #line 19 "parser.yy"
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
 #include "globals.h"
 void yyerror (const char *s);
 extern int yylineno;
@@ -121,7 +124,7 @@ typedef int YYSTYPE;
 
 
 /* Line 216 of yacc.c.  */
-#line 125 "parser.cc"
+#line 128 "parser.cc"
 
 #ifdef short
 # undef short
@@ -408,8 +411,8 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    31,    31,    32,    35,    36,    39,    40,    41,    42,
-      44,    47,    48,    49
+       0,    34,    34,    35,    38,    39,    42,    43,    44,    45,
+      47,    50,    51,    52
 };
 #endif
 
@@ -1318,59 +1321,59 @@ yyreduce:
   switch (yyn)
     {
         case 4:
-#line 35 "parser.yy"
+#line 38 "parser.yy"
     { ++ n; }
     break;
 
   case 5:
-#line 36 "parser.yy"
+#line 39 "parser.yy"
     { deps.clear (); ++ n; }
     break;
 
   case 6:
-#line 39 "parser.yy"
+#line 42 "parser.yy"
     { (yyval) = (yyvsp[(1) - (1)]); deps.push_back ((yyvsp[(1) - (1)])); }
     break;
 
   case 7:
-#line 40 "parser.yy"
+#line 43 "parser.yy"
     { (yyval) = (yyvsp[(3) - (3)]); deps.push_back ((yyvsp[(3) - (3)])); }
     break;
 
   case 8:
-#line 41 "parser.yy"
+#line 44 "parser.yy"
     { (yyval) = (yyvsp[(3) - (3)]); deps.clear (); deps.push_back ((yyvsp[(3) - (3)])); }
     break;
 
   case 9:
-#line 42 "parser.yy"
+#line 45 "parser.yy"
     { (yyval) = (yyvsp[(3) - (3)]); data.add_dependencies ((yyvsp[(3) - (3)]), deps); 
     deps.clear (); deps.push_back ((yyvsp[(3) - (3)])); }
     break;
 
   case 10:
-#line 44 "parser.yy"
+#line 47 "parser.yy"
     { (yyval) = (yyvsp[(3) - (3)]); data.add_delay ((yyvsp[(3) - (3)]), (yyvsp[(1) - (3)]), (yyvsp[(2) - (3)])); }
     break;
 
   case 11:
-#line 47 "parser.yy"
+#line 50 "parser.yy"
     { (yyval) = (yyvsp[(1) - (3)]); data.set_value ((yyvsp[(1) - (3)]), n, timing::sigvalue ((yyvsp[(3) - (3)]))); }
     break;
 
   case 12:
-#line 48 "parser.yy"
+#line 51 "parser.yy"
     { (yyval) = (yyvsp[(1) - (3)]); data.set_value ((yyvsp[(1) - (3)]), n, timing::sigvalue ((yyvsp[(3) - (3)]), timing::STATE)); }
     break;
 
   case 13:
-#line 49 "parser.yy"
+#line 52 "parser.yy"
     { (yyval) = (yyvsp[(1) - (1)]); }
     break;
 
 
 /* Line 1267 of yacc.c.  */
-#line 1374 "parser.cc"
+#line 1377 "parser.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1584,7 +1587,7 @@ yyreturn:
 }
 
 
-#line 51 "parser.yy"
+#line 54 "parser.yy"
 
 
 void yyerror (const char *s) {
