@@ -25,7 +25,27 @@
 #include <iostream>
 #include <sstream>
 #include <exception>
+#ifndef LITE
 #include <Magick++.h>
+#else /* LITE */
+
+namespace Magick
+{
+  struct Coordinate
+  {
+    double _x, _y;
+
+    Coordinate (double x, double y) {
+      _x = x;
+      _y = y;
+    }
+
+    double x (void) const { return _x; }
+    double y (void) const { return _y; }
+  };
+};
+
+#endif /* LITE */
 
 namespace timing {
 
@@ -124,6 +144,7 @@ namespace timing {
     virtual void text (int x, int y, const std::string &text) = 0;
   };
 
+#ifndef LITE
   class magick_gc : public gc {
     std::list<Magick::Drawable> drawables;
 
@@ -147,6 +168,7 @@ namespace timing {
     void draw (Magick::Image& img) const;
   };
 
+#endif /* ! LITE */
   class postscript_gc : public gc {
     std::ostringstream ps_text;
 
